//
// example.c++
//
//	Example library file
//
//
//  Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/

#include <stdlib.h>
#include <limits.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <sysadm/i18n.h>
#include <sysadm/format.h>
#include <rhexamp/RhinoExample.h>

//  It's silly for this code to be here, as each function is used in only
//  one file; it's just here so that the example links with a library of
//  its own, in case you need to do that.

//
//  void AddRhinoExample(SaLog *log, const char *iconName, const char *type, mode_t mode)
//
//  Description:
//      Add an icon to rhinoExample directory.
//
//  Parameters:
//      log       SaLog to write log messages to.
//      iconName  Name of the icon.
//      type      Type of the icon in the ftr database sense.
//      mode      Permissions of the icon.
//
void AddRhinoExample(SaLog *log, const char *iconName, const char *type, mode_t mode)
{
    char buf[PATH_MAX];

    // Make sure icon doesn't already exist.
    (void)SaStringFormat(buf, sizeof buf, "%s/%s", RHINO_EXAMPLE_DIR, iconName);
    if (access(buf, F_OK) == 0) {
	(void)SaLogWriteMsg(log, SaLogError, i18n("%s already exists.\n"),
			    iconName);
	exit(ERR_EXISTS);
    }

    (void)SaLogWriteMsg(log, SaLogMessage,
			i18n("Creating icon file %s"), buf);

    // Create the icon.  Write the type string.
    int fd;
    if ((fd = open(buf, O_WRONLY | O_CREAT, mode)) == -1) {
	(void)SaLogWriteMsg(log, SaLogError, "%s: %s",
			    buf, strerror(errno));
	exit(ERR_CANTCREATE);
    }
    (void)write(fd, type, strlen(type));
    (void)close(fd);
}


//
//  void ModifyRhinoExample(SaLog *log, const char *iconName, const char *type, mode_t mode)
//
//  Description:
//      Add an icon to rhinoExample directory.
//
//  Parameters:
//      log       SaLog to write log messages to.
//      iconName  Name of the icon.
//      type      Type of the icon in the ftr database sense.
//      mode      Permissions of the icon.
//
void ModifyRhinoExample(SaLog *log, const char *iconName, const char *type, mode_t mode)
{
    char buf[PATH_MAX];

    // Make sure icon already exists.
    (void)SaStringFormat(buf, sizeof buf, "%s/%s", RHINO_EXAMPLE_DIR, iconName);
    if (access(buf, F_OK) == -1) {
	(void)SaLogWriteMsg(log, SaLogError, i18n("%s does not exist.\n"),
			    iconName);
	exit(ERR_EXISTS);
    }

    (void)SaLogWriteMsg(log, SaLogMessage,
			i18n("Modifying icon file %s"), buf);

    // Write the type string.
    int fd;
    if ((fd = open(buf, O_WRONLY | O_TRUNC)) == -1) {
	(void)SaLogWriteMsg(log, SaLogError, "%s: %s",
			    buf, strerror(errno));
	exit(ERR_CANTCREATE);
    }
    (void)write(fd, type, strlen(type));
    (void)fchmod(fd, mode);
    (void)close(fd);
}
