//
// rhexampRhinoExampleCategoryRenderers.java
//
//	Attribute Renderer for RhinoExample item table and item view.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.rhexamp.category;

import java.awt.*;
import javax.swing.*;
import com.sgi.sysadm.category.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.ui.richText.*;
import com.sgi.sysadm.util.*;
import com.sgi.rhexamp.*;

/**
 * rhexampRhinoExampleCategoryRenderers implements Renderer interfaces for
 * item tables and item views.  The reason for this code is to
 * translate the RHINO_EXAMPLE_MODE Attribute into something
 * that makes sense to the user.
 */
public class rhexampRhinoExampleCategoryRenderers
                                  implements ItemTableColumnRenderer,
                                             ItemViewAdditionalInfoRenderer,
                                             ItemViewFieldRenderer,
                                             RhinoExampleConstants {

    //------------- ItemTableColumnRenderer methods ------------

    public String getStringForCellOfItemTable(Item item,
                                              String columnName,
                                              ItemTableContext context) {
	Log.assert(columnName.equals("mode-text"),
		   "I don't know how to render: " + columnName);
	return modeString(context.getResourceStack(), item);
    }

    public JComponent getComponentForCellOfItemTable(Item item, 
                                                     String columnName,
                                                     ItemTableContext context) {
	Log.fatal("renderAttrAsComponentForItemTable should never be called");
	return null;
    }

    public String getRichTextForCellOfItemTable(Item item, 
                                                String columnName,
                                                ItemTableContext context) {
	Log.fatal("renderAttrAsRichTextForItemTable should never be called");
	return null;
    }

    public int compareItemsForItemTable(Item item1,  
                                        Item item2, 
                                        String columnName) {
        Log.assert(columnName.equals("mode-icon"),
		   "I don't know how to sort: " + columnName);
        long i1 = item1.getLong(RHINO_EXAMPLE_MODE);
        long i2 = item2.getLong(RHINO_EXAMPLE_MODE);
        if (i1 == i2) return 0;
        if (i1 < i2) return -1;
        return 1;
    }

    //------------- ItemViewAdditionalInfoRenderer methods ------------

    private RichTextComponent _addInfo;

    public void initializeAdditionalInfoRenderer(
	LabelComponentPanel panel, 
	ItemViewContext ivc,
	ItemViewController controller){
	_addInfo = new RichTextComponent("ItemView.AdditionalInfo",
					 ivc.getResourceStack());
	panel.addComponent(_addInfo, "ItemView.AdditionalInfo");
    }

    public void renderInfo(Item item) {
    }
    
    public void renderInfoAgain(Item item) {
    }
    
    public void renderInfoBlank() {
    }

    //------------- ItemViewFieldRenderer methods ------------

    private ItemViewContext _ivContext;
    private ItemViewController _ivController;
    private RLabel _modeLabel;

    public void initializeFieldRenderer(ItemViewContext ivc, 
					    ItemViewController controller) {
	_ivContext = ivc;
	_ivController = controller;
	_modeLabel = _ivController.getRLabelForFieldRenderer();
    }

    public Component getComponentForField(String attr) {
	Log.assert(attr.equals(RHINO_EXAMPLE_MODE),
		   "I don't know how to render: " + RHINO_EXAMPLE_MODE);
	return _modeLabel;
    }

    public void renderFields(Item item) {
	_modeLabel.setText(modeString(_ivContext.getResourceStack(),
				      item));
    }

    public void renderFieldsAgain(Item item) {
	renderFields(item);
    }

    public void renderFieldsBlank() {
	_modeLabel.setText("");
    }

    //------------- private methods ------------

    private String modeString(ResourceStack rs, Item item) {
	long mode = item.getLong(RHINO_EXAMPLE_MODE);
	String lookup = CATEGORY_PACKAGE + RHINO_EXAMPLE_CATEGORY
	    + ".ItemTable.modeStr.";
	if ((mode & 0222) != 0) {
	    lookup += "readWrite";
	} else {
	    lookup += "readOnly";
	}
	return rs.getString(lookup);
    }
}
