//
// RhinoExampleManager.java
//
//	RhinoExample Manager.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.rhexamp.manager;

import java.util.*;
import java.awt.event.*;
import javax.swing.*;
import com.sgi.sysadm.manager.*;
import com.sgi.sysadm.util.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.manager.taskManager.*;

/**
 * RhinoExampleManager is the main program that implements the
 * RhinoExample Manager, which displays an ItemTable of all the
 * RhinoExample items and buttons for some RhinoExample tasks.
 */
public class RhinoExampleManager extends RApp implements TaskManagerFrame {
    private RhinoExampleManagerFrame _frame;
    private ResourceStack _rs;

    private static final String _className =
        RhinoExampleManager.class.getName();

    public static void main(String args[]) {
	new RhinoExampleManager(args).loginAndRun(args);
    }

    public RhinoExampleManager(String[] args) {
	super(_className, null, args);
    }

    public RhinoExampleManager() {
	super(_className, null, (String[])null);
    }

    public RFrame createFrame() {
	_rs = new ResourceStack();
	_rs.pushBundle(_className + ResourceStack.BUNDLE_SUFFIX);
	return _frame = new RhinoExampleManagerFrame(_rs);
    }

    public void setArgs(Vector appArgs, ResultListener listener) {
	listener.succeeded(new ResultEvent(this));
    }

    public void launchApp(final HostContext hc, RAppLaunchListener listener) {
	// Check HostContext to see if RhinoExampleManager is already
	// running.  If so, raise it to the top and don't bother
	// launching ourselves.
	String key = getClass().getName();
	Vector clients = hc.getClients(key);
	if (clients.size() > 0) {
	    ((HostContext.Client)clients.elementAt(0)).getFrame().toFront();
	    _frame.dispose();
	    listener.launchAlreadyRunning(
		new RAppLaunchEvent(this, null));
	    return;
	}	    

	_frame.init(hc);
	_frame.pack();
	_frame.setVisible(true);
	JComponent dialogParent = _frame.getDialogParent();
	UIContext uic = getUIContext();
	uic.setDialogParent(dialogParent);

	// Register ourselves with HostContext so that on subsequent
	// launches we can pop ourselves to the front.
	final HostContext.Client client = new HostContext.Client(_frame, uic);
	hc.registerClient(client, key);
	_frame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
	_frame.addWindowListener(new WindowAdapter() {
 	    public void windowClosed(WindowEvent event) {
 		hc.unregisterClient(client);
		_frame.removeWindowListener((WindowListener)this);
 	    }
	});

	listener.launchSucceeded(
	    new RAppLaunchEvent(this, dialogParent));
    }

    /**
     * Override RApp.run() in order to implement our own scheme for
     * HostContext.registerClient() to get run-once behavior.
     * launchApp() implements the run-once behavior; we override run()
     * to prevent RApp from calling HostContext.registerClient().
     *
     * @param hostContext HostContext to run with.
     * @param RAppLaunchListener Gets notified of launch succcess or failure.
     */
    public void run(final HostContext hostContext,
		    final RAppLaunchListener listener) {
	Log.assert(_frame != null, "initApp() must be called before run()");
	launchApp(hostContext, listener);
    }

    //
    // TaskManagerFrame methods ----------------------------------------
    //

    private HostContext _hc;

    /**
     * @see com.sgi.sysadm.manager.taskManager.TaskManagerFrame
     */
    public void initTaskManagerPlugin(HostContext hc, UIContext uic) {
 	_hc = hc;
    }

    /**
     * @see com.sgi.sysadm.manager.taskManager.TaskManagerFrame
     */
    public void taskManagerLaunchFrame() {
	initApp();
	run(_hc, new RAppLaunchListener() {
	    public void launchSucceeded(RAppLaunchEvent event) {
	    }
	    public void launchFailed(RAppLaunchEvent event) {
	    }
	    public void launchAlreadyRunning(RAppLaunchEvent event) {
	    }
	});
    }
}
