//
// RhinoExampleManagerPanel.java
//
//	Panel for the RhinoExample Manager.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.rhexamp.manager;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.ui.event.*;
import com.sgi.sysadm.util.*;
import com.sgi.sysadm.category.*;
import com.sgi.rhexamp.*;

class RhinoExampleManagerPanel extends RPanel
                               implements RhinoExampleConstants {
    private HostContext _hc;
    private ResourceStack _rs;
    private ItemTable _itemTable;
    private ItemTablePanel _itemTablePanel;
    private UIContext _uic = new UIContext();
    private int _hMargin, _vMargin, _hGap, _vGap;

    /**
     * PanelLayout is a custom layout for the RhinoExample Manager.
     * We place the buttons right-aligned along the bottom of the
     * panel, and size the ItemTable to fit whatever is left over.
     */
    private class PanelLayout implements LayoutManager {
	private Vector _buttons = new Vector();
	public void addLayoutComponent(String name, Component comp) {
	}
	public void removeLayoutComponent(Component comp) {
	}
	public Dimension preferredLayoutSize(Container parent) {
	    Dimension buttonSize = getButtonSize();
	    int numButtons = _buttons.size();
	    int buttonWidth = buttonSize.width * numButtons +
		_hGap * (numButtons - 1);
	    Dimension tableSize = _itemTablePanel.getPreferredSize();

	    int height = _vMargin * 2 + tableSize.height +
		_vGap + buttonSize.height;
	    int width = _hMargin * 2 + Math.max(tableSize.width, buttonWidth);
	    return new Dimension(width, height);
	}
	public Dimension minimumLayoutSize(Container parent) {
	    return new Dimension(1, 1);
	}
	public void layoutContainer(Container parent) {
	    Dimension parentSize = parent.getSize();
	    if (parentSize.width < 1 || parentSize.height < 1) {
		return;
	    }
	    Dimension buttonSize = getButtonSize();
	    int numButtons = _buttons.size();
	    int buttonWidth = buttonSize.width * numButtons +
		_hGap * (numButtons - 1);
	    int x = parentSize.width - _hMargin - buttonWidth;
	    int y = parentSize.height - _vMargin - buttonSize.height;
	    for (int ii = 0; ii < numButtons; ii++) {
		Component comp = (Component)_buttons.elementAt(ii);
		comp.setSize(buttonSize);
		comp.setLocation(x, y);
		x += buttonSize.width + _hGap;
	    }
	    _itemTablePanel.setLocation(_hMargin, _vMargin);
	    _itemTablePanel.setSize(parentSize.width - _hMargin * 2,
				    parentSize.height - _vMargin * 2
				    - _vGap - buttonSize.height);
	}
	private Dimension getButtonSize() {
	    if (_buttons.size() == 0) {
		Component[] kids = getComponents();
		for (int ii = 0; ii < kids.length; ii++) {
		    if (kids[ii] instanceof JButton) {
			_buttons.addElement(kids[ii]);
		    }
		}
	    }
	    int buttonWidth = 0;
	    int buttonHeight = 0;
	    int numButtons = _buttons.size();
	    for (int ii = 0; ii < numButtons; ii++) {
		Dimension size =
		    ((Component)_buttons.elementAt(ii)).getPreferredSize();
		if (size.width > buttonWidth) {
		    buttonWidth = size.width;
		}
		if (size.height > buttonHeight) {
		    buttonHeight = size.height;
		}
	    }
	    return new Dimension(buttonWidth, buttonHeight);
	}
    }

    RhinoExampleManagerPanel(HostContext hc, ResourceStack rs) {
	setLayout(new PanelLayout());
	_hc = hc;
	_rs = rs;
	_uic.setDialogParent(this);
	
	_hMargin = rs.getPixels("panel.hMargin");
	_vMargin = rs.getPixels("panel.vMargin");
	_hGap = rs.getPixels("panel.hGap");
	_vGap = rs.getPixels("panel.vGap");
	try {
            _itemTable = ItemTable.createItemTable(
	    _hc, CATEGORY_PACKAGE + RHINO_EXAMPLE_CATEGORY);
            _itemTablePanel = _itemTable.getItemTablePanel();
        } catch (ItemTableException e) {
            Log.fatal("Got an ItemTableException: " + e);
        }
        
	add(_itemTablePanel);
	_itemTable.setCategory(_hc.getCategory(RHINO_EXAMPLE_CATEGORY));

	JButton addButton = new JButton(_rs.getString("addButton.label"));
	addButton.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent ev) {
		startTask("com.sgi.rhexamp.task.AddRhinoExampleTask", null);
	    }
	});
	add(addButton);

	JButton modifyButton = new JButton(
	    _rs.getString("modifyButton.label"));
	modifyButton.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent ev) {
		startTask("com.sgi.rhexamp.task.ModifyRhinoExampleTask",
			  getSelectedItemSelector());
	    }
	});
	add(modifyButton);

	JButton removeButton = new JButton(
	    _rs.getString("removeButton.label"));
	removeButton.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent ev) {
		startTask("com.sgi.rhexamp.task.RemoveRhinoExampleTask",
			  getSelectedItemSelector());
	    }
	});
	add(removeButton);

	JButton quitButton = new JButton(_rs.getString("quitButton.label"));
	quitButton.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent ev) {
		quit();
	    }
	});
	add(quitButton);
    }

    private String getSelectedItemSelector() {
	Object[] selected = _itemTable.getSelectedObjects();
	if (selected.length > 0) {
	    return ((Item)selected[0]).getSelector();
	}
	return null;
    }

    private void startTask(String taskName, String selectedItem) {
	TaskLoader loader = new TaskLoader(_hc, taskName);
	TaskLaunchRequestEvent ev = new TaskLaunchRequestEvent(this, loader);
	if (selectedItem != null) {
	    Vector operands = new Vector();
	    operands.addElement(selectedItem);
	    ev.setOperands(operands);
	}
	TaskFrame.launchTaskFrame(ev, _uic, TaskFrame.POST_RESULT_PANEL);
    }

    private void quit() {
	Container topLevel = getTopLevelAncestor();
	if (topLevel != null && topLevel instanceof Window) {
	    topLevel.dispatchEvent(
		new WindowEvent((Window)topLevel,
				WindowEvent.WINDOW_CLOSING));
	}
    }
}
