//
// AbstractRhinoExampleForm.java
//
//	Form UI for the Add RhinoExample task.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.rhexamp.task;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;
import com.sgi.sysadm.util.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.ui.taskData.*;
import com.sgi.rhexamp.*;

/**
 * AbstractRhinoExampleForm presents the form UI for the Add RhinoExample task.
 */
abstract class AbstractRhinoExampleForm extends Form implements RhinoExampleConstants {

    // These members have package protection so they are accessible by
    // subclasses.
    TaskContext _taskContext;
    TaskData _taskData;

    private String CLASS_NAME = ResourceStack.getClassName(
	AbstractRhinoExampleForm.class);

    /**
     * Construct an AbstractRhinoExampleForm.
     * 
     * @param taskContext TaskContext contains task, ui, and host stuff.
     */
    public AbstractRhinoExampleForm(TaskContext taskContext) {
	super(taskContext);
	_taskContext = taskContext; 
	_taskData = _taskContext.getTaskData();
    }

    /**
     * Called right before our UI is to be displayed.  Create the
     * components that make up the form's presentation.
     */
    public void createUI() {
	super.createUI();

	ResourceStack rs = _taskContext.getResourceStack();

	createNameField(rs);

	JComboBox typeBox = new JComboBox();
	addTaskComponent(typeBox, CLASS_NAME + ".type");
	String clockItem = rs.getString(CLASS_NAME + ".clockItem");
	typeBox.addItem(clockItem);
	_taskData.addTaskDataBinder(
	    RHINO_EXAMPLE_TYPE,
	    new StringJComboBoxBinder(typeBox, clockItem, "Clock"));
	String printerItem = rs.getString(CLASS_NAME + ".printerItem");
	typeBox.addItem(printerItem);
	_taskData.addTaskDataBinder(
	    RHINO_EXAMPLE_TYPE,
	    new StringJComboBoxBinder(typeBox, printerItem, "Printer"));
	String netscapeItem = rs.getString(CLASS_NAME + ".netscapeItem");
	typeBox.addItem(netscapeItem);
	_taskData.addTaskDataBinder(
	    RHINO_EXAMPLE_TYPE,
	    new StringJComboBoxBinder(typeBox, netscapeItem,
				      "NetscapeExecutable"));

	JPanel permPanel = new JPanel(new GridLayout(2, 1));
	permPanel.setBorder(BorderFactory.createEtchedBorder());
	addTaskComponent(permPanel, CLASS_NAME + ".perm");
	Font font = rs.getFont("RadioButton.font");
	JRadioButton roButton = new RRadioButton(
	    rs.getString(CLASS_NAME + ".roButton"));
	roButton.setFont(font);
	permPanel.add(roButton);
	JRadioButton rwButton = new RRadioButton(
	    rs.getString(CLASS_NAME + ".rwButton"));
	rwButton.setFont(font);
	permPanel.add(rwButton);
	ButtonGroup group = new ButtonGroup();
	group.add(roButton);
	group.add(rwButton);
	_taskData.addTaskDataBinder(
	    AbstractRhinoExampleTask.WRITABLE,
	    new AttributeAbstractButtonBinder(
		roButton,
		new Attribute(AbstractRhinoExampleTask.WRITABLE, false)));
	_taskData.addTaskDataBinder(
	    AbstractRhinoExampleTask.WRITABLE,
	    new AttributeAbstractButtonBinder(
		rwButton,
		new Attribute(AbstractRhinoExampleTask.WRITABLE, true)));
    }

    /**
     * Subclasses override this to add the name field.  For the "Add"
     * task, it's a text field, while for the "Modify" task it's an
     * item finder.
     * 
     * @param rs ResourceStack for UI settings.
     */
    abstract void createNameField(ResourceStack rs);
}
