//
// AbstractRhinoExampleGuide.java
//
//	Guide interface for Add RhinoExample task.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.rhexamp.task;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;
import com.sgi.sysadm.util.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.ui.taskData.*;
import com.sgi.rhexamp.*;

/**
 * AbstractRhinoExampleGuide provides a multi-page Guide interface for the
 * "Add RhinoExample" task.
 */
abstract class AbstractRhinoExampleGuide extends Guide
                                         implements RhinoExampleConstants {

    TaskContext _taskContext;
    TaskData _taskData;

    private static final String CLASS_NAME = ResourceStack.getClassName(
	AbstractRhinoExampleGuide.class);
    private static final String SUMMARY_LABEL = ".summaryLabel";
    
    /**
     * Construct an AbstractRhinoExampleGuide.
     * 
     * @param taskContext TaskContext contains task, ui, and host stuff.
     */
    public AbstractRhinoExampleGuide(TaskContext taskContext) {
	super(taskContext);
	_taskContext = taskContext; 
	_taskData = _taskContext.getTaskData();
    }

    /**
     * Register the pages with our super class.
     */
    public void registerPages() {
     	final ResourceStack rs = _taskContext.getResourceStack();

	// Intro page explains prerequisites.
	GuidePage introPage = new GuidePage(_taskContext,
					    CLASS_NAME + ".introPage");
	appendPage(introPage);
	
	// Name page prompts for the name of the new RhinoExample.
	GuidePage namePage = new GuidePage(_taskContext,
					   CLASS_NAME + ".namePage") {
	    public void createUI() {
		super.createUI();
		createNameField(rs, this);
	    }
	};
	namePage.setVerifier(new TaskDataVerifier() {
	    public void dataOK(int browseFlag, Object context,
			       ResultListener listener) {
		_taskContext.dataOK(RHINO_EXAMPLE_NAME, browseFlag,
				    context, listener);
	    }
	});
	appendPage(namePage);
	
	// Type page prompts for the type of the new RhinoExample.
	appendPage(new GuidePage(_taskContext, CLASS_NAME + ".typePage") {
	    public void createUI() {
		super.createUI();
		String pageName = getPageName();
		JComboBox typeBox = new JComboBox();
		addTaskComponent(typeBox, pageName + ".type");
		String clockItem = rs.getString(pageName + ".clockItem");
		typeBox.addItem(clockItem);
		_taskData.addTaskDataBinder(
		    RHINO_EXAMPLE_TYPE,
		    new StringJComboBoxBinder(typeBox, clockItem,
					      "Clock"));
		String printerItem = rs.getString(pageName + ".printerItem");
		typeBox.addItem(printerItem);
		_taskData.addTaskDataBinder(
		    RHINO_EXAMPLE_TYPE,
		    new StringJComboBoxBinder(typeBox, printerItem,
					      "Printer"));
		String netscapeItem = rs.getString(pageName + ".netscapeItem");
		typeBox.addItem(netscapeItem);
		_taskData.addTaskDataBinder(
		    RHINO_EXAMPLE_TYPE,
		    new StringJComboBoxBinder(typeBox, netscapeItem,
					      "NetscapeExecutable"));
	    }
	});

	// Permissions page prompts for the permissions of the new
	// RhinoExample.
	appendPage(new GuidePage(_taskContext, CLASS_NAME + ".permPage") {
	    public void createUI() {
		super.createUI();
		String pageName = getPageName();
		JPanel permPanel = new JPanel(new GridLayout(2, 1));
		permPanel.setBorder(BorderFactory.createEtchedBorder());
		addTaskComponent(permPanel, pageName + ".perm");
		Font font = rs.getFont("RadioButton.font");
		JRadioButton roButton = new RRadioButton(
		    rs.getString(pageName + ".roButton"));
		roButton.setFont(font);
		permPanel.add(roButton);
		JRadioButton rwButton = new RRadioButton(
		    rs.getString(pageName + ".rwButton"));
		rwButton.setFont(font);
		permPanel.add(rwButton);
		ButtonGroup group = new ButtonGroup();
		group.add(roButton);
		group.add(rwButton);
		_taskData.addTaskDataBinder(
		    AbstractRhinoExampleTask.WRITABLE,
		    new AttributeAbstractButtonBinder(roButton,
			new Attribute(AbstractRhinoExampleTask.WRITABLE,
				      false)));
		_taskData.addTaskDataBinder(
		    AbstractRhinoExampleTask.WRITABLE, 
		    new AttributeAbstractButtonBinder(rwButton,
			new Attribute(AbstractRhinoExampleTask.WRITABLE,
				      true)));
	    }		
	});

	// Summary page gives the user a summary of the choices so far.
	appendPage(new GuidePage(_taskContext, CLASS_NAME + ".summaryPage") {
	    public void createUI() {
		super.createUI();
		final String pageName = getPageName();
		RLabel name = new RLabel(rs, CLASS_NAME + SUMMARY_LABEL);
		_taskData.addTaskDataBinder(RHINO_EXAMPLE_NAME,
					    new StringJLabelBinder(name));
		addTaskComponent(name, pageName + ".name");
		RLabel type = new RLabel(rs, CLASS_NAME + SUMMARY_LABEL);
		_taskData.addTaskDataBinder(RHINO_EXAMPLE_TYPE,
					    new StringJLabelBinder(type));
		addTaskComponent(type, pageName + ".type");
		final RLabel perm = new RLabel(rs, CLASS_NAME + SUMMARY_LABEL);
		_taskData.addTaskDataBinder(AbstractRhinoExampleTask.WRITABLE,
					    new TaskDataBinder() {
		    String rwLabel = rs.getString(pageName + ".rwLabel");
		    String roLabel = rs.getString(pageName + ".roLabel");
		    public void taskDataChanged(TaskDataEvent event) {
			perm.setText(
			    AbstractRhinoExampleGuide.this._taskData.getBoolean(
				AbstractRhinoExampleTask.WRITABLE)
			    ? rwLabel : roLabel);
		    }
		});
		addTaskComponent(perm, pageName + ".perm");
	    }
	});
    }

    /**
     * Subclasses override this to add the name field.  For the "Add"
     * task, it's a text field, while for the "Modify" task it's an
     * item finder.
     * 
     * @param rs ResourceStack for UI settings.
     * @param page Page to add name field to.
     */
    abstract void createNameField(ResourceStack rs, GuidePage page);
}
