//
// ModifyRhinoExampleTask.java
//
//	Task for adding a RhinoExample.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.rhexamp.task;

import java.util.*;
import java.io.*;
import java.text.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.util.*;
import com.sgi.sysadm.category.*;
import com.sgi.sysadm.ui.taskData.*;
import com.sgi.rhexamp.*;

/**
 * ModifyRhinoExampleTask displays UI for adding a RhinoExample.
 */
public class ModifyRhinoExampleTask extends AbstractRhinoExampleTask {

    private static String CLASS_NAME = ResourceStack.getClassName(
	ModifyRhinoExampleTask.class);

    /**
     * Construct an ModifyRhinoExampleTask.
     * 
     * @param taskContext TaskContext contains task, ui, and host stuff.
     */
    public ModifyRhinoExampleTask(TaskContext taskContext) {
	super(taskContext);

	_taskData.addTaskDataBinder(RHINO_EXAMPLE_NAME,
				    new TaskDataBinder() {
	    public void taskDataChanged(TaskDataEvent event) {
		final String name = ModifyRhinoExampleTask.this.
		    _taskData.getString(RHINO_EXAMPLE_NAME).trim();
		if (name.length() == 0) {
		    return;
		}
		NotificationFilter nf = new NotificationFilter();
		nf.monitorItem(name);
		_rhinoExampleCategory.addCategoryListener(
		    new CategoryAdapter() {
		    public void itemAdded(Item item) {
			if (item.getSelector().equals(name)) {
			    ModifyRhinoExampleTask.this.
				_taskData.setAttr(item.getAttr(
				    RHINO_EXAMPLE_TYPE));
			    ModifyRhinoExampleTask.this._taskData.setBoolean(
				WRITABLE,
				(item.getLong(RHINO_EXAMPLE_MODE) & 0222) != 0);
			}
		    }
		    public void endExists() {
			_rhinoExampleCategory.removeCategoryListener(
			    CategoryListener.this);
		    }
		}, nf);
	    }
	});

	_taskContext.appendTaskDataVerifier(RHINO_EXAMPLE_NAME,
					    new TaskDataVerifier() {
	    public void dataOK(int browseFlag, Object context,
			       final ResultListener listener) {
		final String name = _taskData.getString(
		    RHINO_EXAMPLE_NAME).trim();
		if (name.length() == 0) {
		    ResultEvent event = new ResultEvent(this);
		    event.setReason(_rs.getString(
			AbstractRhinoExampleTask.CLASS_NAME
			+ ".Error.missingRhinoExampleName"));
		    listener.failed(event);
		    return;
		}
		RhinoExampleVerifier.verifyItemExists(
		    _rhinoExampleCategory, _rs, name, listener);
	    }
	});
	setPrivilege("rhexampModifyRhinoExample");
    }

    protected void verifyPrereqsBeforeCheckPrivs(ResultListener listener) {
	String name = _taskData.getString(RHINO_EXAMPLE_NAME);
	if (name.length() == 0) {
	    listener.succeeded(new ResultEvent(this));
	    return;
	}
	RhinoExampleVerifier.verifyItemExists(
	    _rhinoExampleCategory, _rs, name, listener);
    }
	
    /**
     * registerInterfaces registers the UI for this task.  A task can
     * have a form interface, a guide interface, or both.
     */
    public void registerInterfaces() {
	setForm(new ModifyRhinoExampleForm(_taskContext));
	setGuide(new ModifyRhinoExampleGuide(_taskContext));
    }
}
