//
// RemoveRhinoExampleTask.java
//
//	Remove RhinoExampleTask.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.rhexamp.task;

import java.util.*;
import java.io.*;
import java.text.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.util.*;
import com.sgi.sysadm.category.*;
import com.sgi.sysadm.ui.taskData.*;
import com.sgi.rhexamp.*;

public class RemoveRhinoExampleTask extends Task
                                    implements RhinoExampleConstants {
    private TaskContext _taskContext;
    private TaskData _taskData;
    private ResourceStack _rs;
    private Category _rhinoExampleCategory;
    private static String CLASS_NAME = ResourceStack.getClassName(
	RemoveRhinoExampleTask.class);
    
    public RemoveRhinoExampleTask(TaskContext taskContext) {
	super(taskContext);

	_taskContext = taskContext;
	_rs = _taskContext.getResourceStack();
	_taskData = _taskContext.getTaskData();
	_rhinoExampleCategory = taskContext.getHostContext().getCategory(
		RHINO_EXAMPLE_CATEGORY);
	_taskData.setString(RHINO_EXAMPLE_NAME, "");
	_taskContext.appendTaskDataVerifier(RHINO_EXAMPLE_NAME,
					    new TaskDataVerifier() {
	    public void dataOK(int browseFlag, Object context,
			       final ResultListener listener) {
		final String name = _taskData.getString(
		    RHINO_EXAMPLE_NAME).trim();
		if (name.length() == 0) {
		    if (browseFlag == TaskDataVerifier.MUST_BE_SET) {
			ResultEvent event = new ResultEvent(Task.this);
			event.setReason(_rs.getString(
			    AbstractRhinoExampleTask.CLASS_NAME
			    + ".Error.missingRhinoExampleName"));
			listener.failed(event);
		    } else {
			listener.succeeded(new ResultEvent(this));
		    }
		    return;
		}
		RhinoExampleVerifier.verifyItemExists(
		    _rhinoExampleCategory, _rs, name, listener);
	    }
	});
    }

    public void setOperands(Vector operands) throws TaskInitFailedException {
	if (operands == null || operands.size() == 0) {
	    return;
	}
	if (operands.size() > 1) {
	    throw new TaskInitFailedException(_rs.getString(
		"Error.tooManyOperands"),
		TaskInitFailedException.INVALID_OPERANDS);
	}

	try {
	    _taskData.setString(RHINO_EXAMPLE_NAME,
				(String)operands.elementAt(0));
	} catch (ClassCastException ex) {
	    throw new TaskInitFailedException(_rs.getString(
		"Error.invalidOperand"),
		TaskInitFailedException.INVALID_OPERANDS);
	}
    }

    /**
     * registerInterfaces registers the UI for this task.  A task can
     * have a form interface, a guide interface, or both.
     */
    public void registerInterfaces() {
	setForm(new Form(_taskContext) {
	    public void createUI() {
		super.createUI();
		ItemFinder finder =
                    new ItemFinder(null, (ItemDisplayNameRenderer)null, null);
		finder.setCategory(_rhinoExampleCategory);
		_taskData.addTaskDataBinder(
		    RHINO_EXAMPLE_NAME,
		    new SelectorItemFinderBinder(finder));
		addTaskComponent(
		    finder, RemoveRhinoExampleTask.this.CLASS_NAME + ".finder");
	    }
	});
    }
    
    public void ok() {
	try {
	    runPriv("rhexampRemoveRhinoExample", _taskData).close();
	} catch (IOException ex) {
	    Log.debug(CLASS_NAME, ex.getMessage());
	    Log.debug(CLASS_NAME, SysUtil.stackTraceToString(ex));
	}
    }

   /**
     * Create a result panel describing the successful task completion.
     * @see com.sgi.sysadm.ui.Task#createResultViewPanel()
     */
    public ResultViewPanel createResultViewPanel() {
	return new ResultViewPanel(
	    _taskContext, _rs, RHINO_EXAMPLE_CATEGORY,
	    MessageFormat.format(
		_rs.getString(CLASS_NAME + ".succeeded"),
		new Object[] {_taskData.getString(RHINO_EXAMPLE_NAME) }));
    }
}
