//
// rhexampModifyRhinoExample.c++
//
//	rhexampModifyRhinoExample privilege command
//
//
//  Copyright (c) 1995, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

#ident "$Revision: 1.4 $"

#include <sys/types.h>
#include <sys/stat.h>

#include <stdlib.h>
#include <limits.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <locale.h>

#include <sysadm/i18n.h>
#include <sysadm/SaParam.h>
#include <sysadm/format.h>

#include <rhexamp/RhinoExample.h>

//
// rhexampModifyRhinoExample main program.  Parse command line args
// and call rhexampModifyRhinoExample.
//
void main(int argc, char *argv[])
{
    SaLogErrorCode code;
    SaLog *log = NULL;
    if ((code = SaLogOpen("rhexampModifyRhinoExample", &log)) 
	!= SaLogErrNoError) {
	(void)fprintf(stderr, "rhexampModifyRhinoExample: salog: %s\n",
		      SaLogErrorCodeToString(code));
	exit(SaPRIVNOLOG);
    }
	
    SaParam* params = SaParamCreate();
    if (params == NULL || SaParamParseArgs(params, argc, argv) == -1) {
	SaLogWriteMsg(log, SaLogError, 
                      i18n("usage: modifyRhinoExample name=<example-name> "
                           "type=<example-type> mode=<example-mode>\n"));
	exit(ERR_USAGE);
    }

    const char* iconName = SaParamGet(params, RHINO_EXAMPLE_NAME);
    const char* type = SaParamGet(params, RHINO_EXAMPLE_TYPE);
    const char* modeString = SaParamGet(params, RHINO_EXAMPLE_MODE);
    mode_t mode;
    if (iconName == NULL || type == NULL || modeString == NULL
	|| sscanf(modeString, "%o", &mode) != 1) {
	SaLogWriteMsg(log, SaLogError,
                      i18n("usage: modifyRhinoExample name=<example-name> "
                           "type=<example-type> mode=<example-mode>\n"));
	exit(ERR_USAGE);
    }
    ModifyRhinoExample(log, iconName, type, mode);
    SaLogClose(log);
    exit(0);
}
