//
// rhexampRemoveRhinoExample.c++
//
//	rhexampRemoveRhinoExample privilege command
//
//
//  Copyright (c) 1995, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

#ident "$Revision: 1.9 $"

#include <stdio.h>
#include <limits.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>
#include <locale.h>

#include <sysadm/i18n.h>
#include <sysadm/SaParam.h>
#include <sysadm/format.h>

#include <rhexamp/RhinoExample.h>

//
// rhexampRemoveRhinoExample main program.
//
void main(int argc, char *argv[])
{
    SaLogErrorCode code;
    SaLog *log;
    if ((code = SaLogOpen("rhexampRemoveRhinoExample", &log)) 
	!= SaLogErrNoError) {
	(void)fprintf(stderr, "rhexampRemoveRhinoExample: salog: %s\n",
		      SaLogErrorCodeToString(code));
	exit(SaPRIVNOLOG);
    }

    SaParam* param = SaParamCreate();
    const char* iconName;
    if (param == NULL || SaParamParseArgs(param, argc, argv) == -1
	|| (iconName = SaParamGet(param, RHINO_EXAMPLE_NAME)) == NULL) {
	SaLogWriteMsg(log, SaLogError, i18n("usage: rhexampRemoveRhinoExample "
                                            "name=<example-name>\n"));
	exit(ERR_USAGE);
    }

    // Make sure icon exists.
    char buf[PATH_MAX];
    (void)SaStringFormat(buf, sizeof buf, "%s/%s", RHINO_EXAMPLE_DIR, iconName);
    if (access(buf, F_OK) != 0) {
	SaLogWriteMsg(log, SaLogError, i18n("%s does not exist.\n"), iconName);
	exit(ERR_NOTTHERE);
    }

    SaLogWriteMsg(log, SaLogMessage, i18n("Deleting icon file %s"), buf);

    // Try to remove it.
    if (unlink(buf) == -1) {
	SaLogWriteMsg(log, SaLogError, i18n("Can't remove %s: %s\n"),
		      iconName, strerror(errno));
	exit(ERR_CANTREMOVE);
    }

    SaLogClose(log);
    exit(0);
}
