//
// CategoryErrorEvent.c++
//
//	Get notification when an error occurs on a Category.
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2.1 of the GNU Lesser General Public
//  License as published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this program; if not, write the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
//  USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

#ident "$Revision: 1.4 $"

#include <sysadm/CategoryErrorEvent.h>

BEGIN_NAMESPACE(sysadm);

//
// CategoryErrorEvent implementation.
//
class CategoryErrorEventImpl {
  public:
    CategoryErrorEventImpl(const Category& source, const String& reason) :
        _source(source), _reason(reason) {
    }

    const Category& _source;
    const String& _reason;
};


//
//  CategoryErrorEvent::CategoryErrorEvent(const Category& source, const String& reason)
//
//  Description:
//      Constructor
//
//  Parameters:
//      source	Category associated with this event.
//      reason	Localized string describing the error.
//
CategoryErrorEvent::CategoryErrorEvent(const Category& source, const String& reason)
 : _impl(new CategoryErrorEventImpl(source, reason)) {
}


//
//  CategoryErrorEvent::~CategoryErrorEvent()
//
//  Description:
//      Destructor.
//
CategoryErrorEvent::~CategoryErrorEvent()
 {
    delete _impl;
}


//
//  const Category* CategoryErrorEvent::getCategory()
//
//  Description:
//      Access the Category object associated with this event.
//
//  Returns:
//	The Category object associated with this event.
//
const Category& CategoryErrorEvent::getCategory() {
    return _impl->_source;
}

//
//  const String* CategoryErrorEvent::getErrorString() 
//
//  Description:
//      Access the localized string describing the error.
//
//  Returns:
//	The localized string describing the error.
//
const String& CategoryErrorEvent::getErrorString() {
    return _impl->_reason;
}

END_NAMESPACE(sysadm);
