//
//  Copyright (c) 1995, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2.1 of the GNU Lesser General Public
//  License as published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this program; if not, write the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
//  USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

#ifndef _SYSADM_COLLECTIONS_P_H
#define _SYSADM_COLLECTIONS_P_H

BEGIN_NAMESPACE(sysadm);

#define USE_RECYCLED_DLINKS

/**
*  This is used by several of the collection implimentations.
*  DLink is a generic doubly linked list node
*/

class DLink {
  public:
    DLink( void* data = NULL ) : _prev(NULL), _next(NULL), _data(data) 
    {
    }
    
    ~DLink() {}

    void insertBefore( DLink* newLink );
    void insertAfter( DLink* newLink );
    void remove();

    DLink* _prev;
    DLink* _next;

    void*  _data;

#ifdef USE_RECYCLED_DLINKS
    void* operator new( size_t size );
    void  operator delete( void* item );

    class Recycler {
      public:
	Recycler();
	~Recycler();

	DLink* fetch();
	void put( DLink* item );

	static DLink* _list;
	static long      _liveCount;
	static long      _deadCount;
    };
#endif
};

END_NAMESPACE(sysadm);
#endif  //  _SYSADM_COLLECTIONS_P_H
