//
// ItemNameRendererFormat.java
//
//	Specifies a format and arguments to used to render an item name.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2.1 of the GNU Lesser General Public
//  License as published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this program; if not, write the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
//  USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.sysadm.ui;

import java.util.*;
import java.awt.*;

/**
 * A ItemNameRendererFormat is used to specify the format to be used to render
 * the string name of an Item.  It contains two items:<UL>
 * <LI>a String specifying the format of the name; and
 * <LI>a String[] containing the names of the item attributes
 * </UL>
 * The format and attribute values are passed to MessageFormat.format
 * to build the final name.
 *
 * @author	John Relph
 * @version	$Revision: 1.3 $ $Date: 2000/07/24 21:58:15 $
 *
 */
public class ItemNameRendererFormat extends Object {

    String _format;
    String[] _attributes;

    /**
     * Construct a ItemNameRendererFormat.
     *
     * @param format A format string in the style of
     *               java.text.MessageFormat
     * @param attributes The keys of Attributes whose values will be
     *                   substituted into the format string.
     */
    public ItemNameRendererFormat(String format, String[] attributes) {
	_format = format;
	_attributes = attributes;
    }
}
