//
// ItemTableLaunchRequestEvent
//   
//	An event describing a request to launch an ITemTable
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2.1 of the GNU Lesser General Public
//  License as published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this program; if not, write the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
//  USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.sysadm.ui.event;

import java.util.*;

/**
 * An object that specifies an ItemTable.  From the data contained in
 * this object, an ItemTableLaunchRequestListener can
 * create an ItemTable of the type that the <tt>source</tt> is
 * requesting be launched.
 * <p>
 * See the ItemTableLaunchRequestListener documentation about how this
 * event is used.
 *
 * @see ItemTableLaunchRequestListener
 * @see ItemTable
 */
public class ItemTableLaunchRequestEvent extends EventObject {
    
    private String _categorySelector;
    
    /** 
     * A constructor that takes the selector of the Category of the
     * ItemTable to launch.
     *
     * @param source The source of this event
     * @param categorySelector The Category of the ItemTable to launch.
     */
    public ItemTableLaunchRequestEvent(Object source, 
				       String categorySelector) {
	super(source);
	_categorySelector = categorySelector;
    }
    
    /** 
     * Returns the selector of the Category for which to launch an ItemTable
     *
     * @return The selector of the Category
     */
    public String getCategorySelector() {
	return _categorySelector;
    }
}
