//
// LineBreak.java
//
//	Scene graph element that draws a line break.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2.1 of the GNU Lesser General Public
//  License as published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this program; if not, write the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
//  USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.sysadm.ui.richText;

import java.awt.*;

/**
 * LineBreak objects are inserted between Paragraphs in a Document to
 * set them apart from each other.
 */
class LineBreak extends TextBlock {

    /**
     * Set geometry.  The height of a newline is just the height of a
     * line.
     * 
     * @param state Graphics parameters.
     * @param y Our top edge.
     * @param componentWidth Width of our RichText component.
     */
    void setGeometry(GraphicsState state, int y, int componentWidth) {
	_x = 0;
	_y = y;
	_width = componentWidth;

	_height = (int)(state._fontMetrics.getHeight()
			* state._lineBreakScale);
    }

    /**
     * Newlines don't have to be drawn.
     * 
     * @param state Drawing parameters.
     */
    void draw(GraphicsState state) {
    }
}
