//
// AttrListener.java
//
//	Notification of Attribute (within an AttrBundle) changes.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2.1 of the GNU Lesser General Public
//  License as published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU Lesser General Public
//  License along with this program; if not, write the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307,
//  USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package com.sgi.sysadm.util;

import java.util.EventListener;

/**
 * Interface for getting notified when an Attribute within an
 * AttrBundle is added, changed, or removed.
 * @see AttrBundle
 * @see Attribute
 */
public interface AttrListener extends EventListener {

    /**
     * Called when an Attribute is added to a AttrBundle.
     *
     * @param event specifies the Attribute that was added.
     */
    public void attrAdded(AttrEvent event); 

    /**
     * Called when an Attribute within an AttrBundle changes.
     * 
     * @param event specifies the Attribute that changed.
     */
    public void attrChanged(AttrEvent event);

    /**
     * Called when an Attribute is removed from a AttrBundle.
     *
     * @param event specifies the Attribute that was deleted.
     */
    public void attrRemoved(AttrEvent event);
}
