//
// MakeRhinoIsmGuide.java
//
//	UI for the "make rhino ism" task.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package mkrhinoism.task;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;
import com.sgi.sysadm.util.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.ui.taskData.*;

public class MakeRhinoIsmGuide extends Guide {
    TaskContext _taskContext;
    TaskData _taskData;
    ResourceStack _resStack;
    RLabel _root;
    RLabel _troot;

    private class MakeRhinoIsmGuidePage extends GuidePage {
	String _key;
	MakeRhinoIsmGuidePage(String pageName, final String key) {
	    super(MakeRhinoIsmGuide.this._taskContext, pageName);
	    _key = key;
	    setVerifier(new TaskDataVerifier() {
		public void dataOK(int browseFlag, Object context,
				   ResultListener listener) {
		    MakeRhinoIsmGuide.this._taskContext.dataOK(
			key, browseFlag, context, listener);
		}
	    });
	}
	public void createUI() {
	    super.createUI();
	    String pageName = getPageName();
	    RTextField text = new RTextField(_resStack.getInt(
		pageName + ".text.length"));
	    addTaskComponent(text, getPageName() + ".text");
	    StringJTextComponentBinder.bind(_taskData, _key, text);
	}
    }

    private class RootLabelsVisibleBinder extends TaskDataBinder {
	public void taskDataChanged(TaskDataEvent ev) {
	    TaskData tdata = ev.getTaskData();
	    boolean showInputs =
		tdata.getBoolean(MakeRhinoIsmTask.CREATE_ROOT);
	    if (!showInputs) {
		_root.setVisible(false);
		_troot.setVisible(false);
		return;
	    }
	    _root.setVisible(
		tdata.getString(MakeRhinoIsmTask.ROOT).length() > 0);
	    _troot.setVisible(
		tdata.getString(MakeRhinoIsmTask.TROOT).length() > 0);
	}
    }

    public MakeRhinoIsmGuide(TaskContext taskContext) {
	super(taskContext);
	_taskContext = taskContext; 
	_taskData = _taskContext.getTaskData();
	_resStack = _taskContext.getResourceStack();
    }

    public void registerPages() {
	appendPage(new GuidePage(_taskContext, "introPage"));
	appendPage(new MakeRhinoIsmGuidePage("objPage",
					     MakeRhinoIsmTask.OBJECT));
	appendPage(new MakeRhinoIsmGuidePage("ismPage", MakeRhinoIsmTask.ISM));
	appendPage(new MakeRhinoIsmGuidePage("productPage",
					  MakeRhinoIsmTask.PRODUCT));
	appendPage(new MakeRhinoIsmGuidePage("dirPage", MakeRhinoIsmTask.DIR));
	
//	appendPage(new GuidePage(_taskContext, "rootPage") {
//	    public void createUI() {
//		super.createUI();
//		final String pageName = getPageName();
//		RCheckBox check = new RCheckBox(_resStack.getString(
//		    pageName + ".check.label"));
//		addTaskComponent(check);
//		BooleanAbstractButtonBinder.bind(_taskData,
//						 MakeRhinoIsmTask.CREATE_ROOT,
//						 check);
//		final JPanel borderPanel = new JPanel();
//		borderPanel.setBorder(BorderFactory.createEtchedBorder());
//		TaskPage panel = new TaskPage(_resStack);
//		int borderWidth = _resStack.getPixels(
//		    pageName + ".borderWidth");
//		int borderHeight = _resStack.getPixels(
//		    pageName + ".borderHeight");
//		panel.setBorder(BorderFactory.createEmptyBorder(
//		    borderHeight, borderWidth, borderHeight, borderWidth));
//		borderPanel.add(panel);
//		addTaskComponent(borderPanel);
//		RTextField root = new RTextField(20);
//		StringJTextComponentBinder.bind(_taskData,
//						MakeRhinoIsmTask.ROOT,
//						root);
//		panel.addOptionalTaskComponent(root, pageName + ".root");
//		RTextField troot = new RTextField(20);
//		StringJTextComponentBinder.bind(_taskData,
//						MakeRhinoIsmTask.TROOT,
//						troot);
//		panel.addOptionalTaskComponent(troot, pageName + ".troot");
//		
//		// We add this binder AFTER all the other components
//		// have been created, otherwise we'll get a null
//		// pointer exception when we try to setVisible.
//		_taskData.addTaskDataBinder(MakeRhinoIsmTask.CREATE_ROOT,
//					    new TaskDataBinder() {
//
//		    public void taskDataChanged(TaskDataEvent ev) {
//			TaskData tdata = ev.getTaskData();
//			boolean showInputs =
//			    tdata.getBoolean(MakeRhinoIsmTask.CREATE_ROOT);
//			borderPanel.setVisible(showInputs);
//			borderPanel.validate();
//			validate();
//		    }
//		});
//		setVerifier(new TaskDataVerifier() {
//		    public void dataOK(final int browseFlag,
//				       final Object context,
//				       final ResultListener listener) {
//			MakeRhinoIsmGuide.this._taskContext.
//			    dataOK(MakeRhinoIsmTask.ROOT, browseFlag, context,
//				   new ResultAdapter(listener) {
//				public void succeeded(ResultEvent ev) {
//				    MakeRhinoIsmGuide.this._taskContext.
//					dataOK(MakeRhinoIsmTask.TROOT,
//					       browseFlag, context, listener);
//				    
//				}
//			    });
//		    }
//		});
//	    }						 
//	});

	appendPage(new GuidePage(_taskContext, "summaryPage") {
	    public void createUI() {
		super.createUI();
		final String pageName = getPageName();
		RLabel obj = new RLabel(_resStack);
		StringJLabelBinder.bind(_taskData,
					MakeRhinoIsmTask.OBJECT, obj);
		addTaskComponent(obj, pageName + ".obj");
		RLabel ism = new RLabel(_resStack);
		StringJLabelBinder.bind(_taskData, MakeRhinoIsmTask.ISM, ism);
		addTaskComponent(ism, pageName + ".ism");
		RLabel product = new RLabel(_resStack);
		StringJLabelBinder.bind(_taskData,
					MakeRhinoIsmTask.PRODUCT,
					product);
		addTaskComponent(product, pageName + ".product");
		RLabel dir = new RLabel(_resStack);
		StringJLabelBinder.bind(_taskData, MakeRhinoIsmTask.DIR, dir);
		addTaskComponent(dir, pageName + ".dir");

		_root = new RLabel(_resStack);
		StringJLabelBinder.bind(_taskData, MakeRhinoIsmTask.ROOT,
					_root);
		addTaskComponent(_root, pageName + ".root");

		_troot = new RLabel(_resStack);
		StringJLabelBinder.bind(_taskData, MakeRhinoIsmTask.TROOT,
					_troot);
		addTaskComponent(_troot, pageName + ".troot");

		_taskData.addTaskDataBinder(MakeRhinoIsmTask.CREATE_ROOT,
					    new RootLabelsVisibleBinder());
		_taskData.addTaskDataBinder(MakeRhinoIsmTask.ROOT,
					    new RootLabelsVisibleBinder());
		_taskData.addTaskDataBinder(MakeRhinoIsmTask.TROOT,
					    new RootLabelsVisibleBinder());
	    }
	});
    }
}
