//
// MakeRhinoIsmTask.java
//
//	Task to create a Rhino ism.
//
//
//  Copyright (c) 1998, 2000 Silicon Graphics, Inc.  All Rights Reserved.
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of version 2 of the GNU General Public License as
//  published by the Free Software Foundation.
//  
//  This program is distributed in the hope that it would be useful, but
//  WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  
//  Further, this software is distributed without any warranty that it is
//  free of the rightful claim of any third person regarding infringement
//  or the like.  Any license provided herein, whether implied or
//  otherwise, applies only to this software file.  Patent licenses, if
//  any, provided herein do not apply to combinations of this program
//  with other software, or any other product whatsoever.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write the Free Software Foundation,
//  Inc., 59 Temple Place - Suite 330, Boston MA 02111-1307, USA.
//  
//  Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
//  Mountain View, CA 94043, or http://www.sgi.com/
//  
//  For further information regarding this notice, see:
//  http://oss.sgi.com/projects/GenInfo/NoticeExplan/
//

package mkrhinoism.task;

import java.util.*;
import java.io.*;
import java.text.*;
import java.awt.event.*;
import java.awt.*;
import javax.swing.*;
import com.sgi.sysadm.ui.*;
import com.sgi.sysadm.util.*;
import com.sgi.sysadm.category.*;
import com.sgi.sysadm.ui.taskData.*;

public class MakeRhinoIsmTask extends Task {

    TaskContext _taskContext;
    TaskData _taskData;
    ResourceStack _rs;
    private StatusPanel _statusPanel;
    private JDialog _statusDialog;
    private Process _privProc;
    private ProcessWatcher _watcher;
    private PrivListener _privListener;

    static final String OBJECT = "object";
    static final String PRODUCT = "product";
    static final String DIR = "dir";
    static final String ISM = "ism";
    static final String BUILD_STYLE = "buildStyle";
    static final String BUILD_STYLE_GNU = "gnu";
    static final String BUILD_STYLE_SGI = "sgi";
    static final String ROOT = "root";
    static final String TROOT = "troot";
    static final String CREATE_ROOT = "createRoot";

    private static String _class = ResourceStack.getClassName(
	MakeRhinoIsmTask.class);

    private class DataVerifier implements TaskDataVerifier {
	String _key;
	DataVerifier(String key) {
	    _key = key;
	}
	public void dataOK(int browseFlag, Object context,
			   ResultListener listener) {
	    String name = _taskData.getString(_key);
	    if (name.length() == 0) {
		if (browseFlag == TaskDataVerifier.MUST_BE_SET) {
		    ResultEvent event = new ResultEvent(Task.this);
		    event.setReason(_rs.getString(_key + ".Error.missing"));
		    listener.failed(event);
		} else {
		    listener.succeeded(new ResultEvent(this));
		}
		return;
	    }
	    if (!_key.equals(DIR)) {
		char[] chars = new char[name.length()];
		name.getChars(0, name.length(), chars, 0);
		for (int ii = 0; ii < chars.length; ii++) {
		    char c = chars[ii];
		    if (!Character.isLetterOrDigit(c) && c != '_') {
			ResultEvent event = new ResultEvent(Task.this);
			event.setReason(_rs.getString(
			    _key + ".Error.illegalCharInName"));
			listener.failed(event);
			return;
		    }
		}
	    }
	    listener.succeeded(new ResultEvent(Task.this));
	}
    }

    private class BuildStyleVerifier implements TaskDataVerifier {
	BuildStyleVerifier() {
	}
	public void dataOK(int browseFlag, Object context,
			   ResultListener listener) {
	    String style = _taskData.getString(BUILD_STYLE);
            if (style.equals("")) {
                ResultEvent event = new ResultEvent(this);
	        event.setReason(_rs.getString(BUILD_STYLE + ".Error.missing"));
                listener.failed(event);
                return;
            }
            if ((style.equals(BUILD_STYLE_GNU) ||
                 style.equals(BUILD_STYLE_SGI))) {
                listener.succeeded(new ResultEvent(this));
                return;
            }
            ResultEvent event = new ResultEvent(this);
	    event.setReason(_rs.getString(BUILD_STYLE + ".Error.badBuildStyle"));
	    listener.failed(event);
	}
    }

    private class RootVerifier implements TaskDataVerifier {
	String _key;
	RootVerifier(String key) {
	    _key = key;
	}
	public void dataOK(int browseFlag, Object context,
			   ResultListener listener) {
	    String name = _taskData.getString(_key);
	    if (name.length() == 0) {
		listener.succeeded(new ResultEvent(this));
		return;
	    }
	    if (name.length() < 2 || name.charAt(0) != '/') {
		ResultEvent event = new ResultEvent(Task.this);
		event.setReason(_rs.getString(
		    _key + ".Error.badRootFormat"));
		listener.failed(event);
		return;
	    }
	    listener.succeeded(new ResultEvent(this));
	}
    }

    private class StatusPanelLayout implements LayoutManager {
	StatusPanel _panel;
	int _hmargin, _vmargin, _vgap;
	StatusPanelLayout(StatusPanel panel) {
	    _panel = panel;
	    _hmargin = _rs.getInt(_class + ".hmargin");
	    _vmargin = _rs.getInt(_class + ".vmargin");
	    _vgap = _rs.getInt(_class + ".vgap");
	}
	public void addLayoutComponent(String name, Component comp) {
	}
	public void removeLayoutComponent(Component comp) {
	}
	public Dimension preferredLayoutSize(Container parent) {
	    Insets insets = parent.getInsets();
	    int width = insets.left + insets.right + _hmargin * 2;
	    int height = insets.top + insets.bottom + _vmargin * 2 +
		_vgap * 2;
	    Dimension labelSize = _panel._label.getPreferredSize();
	    Dimension scrollSize = _panel._scroll.getPreferredSize();
	    Dimension buttonSize = _panel._cancelButton.getPreferredSize();
	    width += Math.max(scrollSize.width, buttonSize.width);
	    height += scrollSize.height + buttonSize.height + labelSize.height;
	    return new Dimension(width, height);
	}
	public Dimension minimumLayoutSize(Container parent) {
	    return new Dimension(1, 1);
	}
	public void layoutContainer(Container parent) {
	    Dimension parentSize = parent.getSize();
	    if (parentSize.width < 1) {
		return;
	    }
	    Insets insets = parent.getInsets();
	    int componentWidth = parentSize.width - _hmargin * 2 -
		insets.left - insets.right;
	    int x = _hmargin + insets.left;
	    Dimension buttonSize = _panel._cancelButton.getPreferredSize();
	    Dimension labelSize = _panel._label.getPreferredSize();
	    _panel._label.setSize(componentWidth, labelSize.height);
	    _panel._label.setLocation(insets.left + _hmargin,
				      insets.top + _vmargin);
	    _panel._cancelButton.setSize(buttonSize);
	    int y = parentSize.height - buttonSize.height -
		insets.bottom - _vmargin;
	    _panel._cancelButton.setLocation(
		parentSize.width - buttonSize.width - insets.right - _hmargin,
		y);
	    _panel._scroll.setSize(
		componentWidth,
		y - _vmargin - _vgap * 2 - insets.top - labelSize.height);
	    _panel._scroll.setLocation(
		insets.left + _hmargin,
		insets.top + _vmargin + _vgap + labelSize.height);
	}
    }

    private class StatusPanel extends JPanel implements ActionListener {
	JTextArea _text;
	JButton _cancelButton;
	JScrollPane _scroll;
	RLabel _label;
	boolean _succeeded = false;
	StatusPanel() {
	    setLayout(new StatusPanelLayout(this));
	    _label = new RLabel(_rs);
	    _label.setText(_rs.getString(_class + ".status.inProgress"));
	    add(_label);
	    _text = new JTextArea();
	    _text.setEditable(false);
	    _scroll = new JScrollPane(_text);
	    _text.setRows(_rs.getInt(_class + ".textRows"));
	    _text.setColumns(_rs.getInt(_class + ".textColumns"));
	    add(_scroll);
	    _cancelButton = new JButton(
		_rs.getString(_class + ".cancelButtonLabel"));
	    add(_cancelButton);
	    _cancelButton.addActionListener(this);
	}
	public void actionPerformed(ActionEvent ev) {
	    _privProc.destroy();
	    _statusDialog.dispatchEvent(
		new WindowEvent(_statusDialog, WindowEvent.WINDOW_CLOSING));
	    if (!_succeeded) {
		taskFailed(null);
	    } else {
		taskSucceeded(new ResultEvent(Task.this));
	    }
	}
	void success() {
	    _label.setText(_rs.getString(_class + ".status.succeeded"));
	    _succeeded = true;
	    changeToCloseButton();
	}
	void failure() {
	    _label.setText(_rs.getString(_class + ".status.failed"));
	    changeToCloseButton();
	}
	void changeToCloseButton() {
	    _cancelButton.setText(_rs.getString(_class + ".closeButtonLabel"));
	}
    }

    private class PrivListener implements ProcessListener {
	StringBuffer _error = new StringBuffer();
	StringBuffer _output = new StringBuffer();
	public void processErrorData(ProcessEvent event) {
	    String errorString = new String(event.getBytes());
	    _error.append(errorString);
	    _statusPanel._text.append(errorString);
	}
	public void processExited(ProcessEvent event) {
	    if (event.getExitCode() == 0) {
		_statusPanel.success();
	    } else {
		_statusPanel.failure();
		_taskContext.postError(_error.toString());
	    }
	}
	public void processOutputData(ProcessEvent event) {
	    _output.append(new String(new String(event.getBytes())));
	    if (_output.length() == 0) {
		// This seems unlikely, but just in case...
		return;
	    }
	    if (_output.charAt(_output.length() - 1) == '\n') {
		_statusPanel._text.append(_output.toString());
		_output.setLength(0);
	    }
	}
    }

    public MakeRhinoIsmTask(TaskContext taskContext) {
	super(taskContext);

	_taskContext = taskContext;
	_rs = _taskContext.getResourceStack();
	_taskData = _taskContext.getTaskData();
	_taskData.setString(OBJECT, "");
	_taskData.setString(PRODUCT, "");
	_taskData.setString(DIR, "");
	_taskData.setString(ISM, "");
	_taskData.setString(BUILD_STYLE, _rs.getString(BUILD_STYLE + ".default"));
	_taskData.setString(ROOT, "/rhinoroot");
	_taskData.setString(TROOT, "/rhinotroot");
	_taskData.setBoolean(CREATE_ROOT,
            _taskData.getString(BUILD_STYLE).equals(BUILD_STYLE_SGI));

	_taskContext.appendTaskDataVerifier(OBJECT, new DataVerifier(OBJECT));
	_taskContext.appendTaskDataVerifier(PRODUCT, new DataVerifier(PRODUCT));
	_taskContext.appendTaskDataVerifier(DIR, new DataVerifier(DIR));
	_taskContext.appendTaskDataVerifier(ISM, new DataVerifier(ISM));
	_taskContext.appendTaskDataVerifier(BUILD_STYLE, new BuildStyleVerifier());
	_taskContext.appendTaskDataVerifier(ROOT, new RootVerifier(ROOT));
	_taskContext.appendTaskDataVerifier(TROOT, new RootVerifier(TROOT));
    }

    public void registerInterfaces() {
	setGuide(new MakeRhinoIsmGuide(_taskContext));
    }

    public void ok() {
	_statusPanel = new StatusPanel();
	_taskContext.postDialog(
	    _statusPanel, _rs.getString(_class + ".statusDialogTitle"),
	    new ResultListener() {
	    public void succeeded(ResultEvent ev) {
		_statusDialog = (JDialog)ev.getResult();
		_statusDialog.addWindowListener(new WindowAdapter() {
		    public void windowClosing(WindowEvent event) {
			_watcher.removeProcessListener(_privListener);
			_watcher = null;
			_privListener = null;
			_privProc = null;
			_statusDialog.dispose();
			_statusDialog = null;
			_statusPanel = null;
		    }
		});
		makeRhinoIsm();
	    }
	    public void failed(ResultEvent ev) {
		Log.fatal("Can't post my status dialog");
	    }
	});
    }

    private void makeRhinoIsm() {
	TaskData args = new TaskData();

	// Just in case the user types "sysadm_" even after we've
	// asked them not to.
	String product = _taskData.getString(PRODUCT);
	if (product.startsWith("sysadm_")) {
	    product = product.substring(7, product.length());
	}
	args.setString(PRODUCT, product);
	args.setAttr(_taskData.getAttr(OBJECT));
	args.setAttr(_taskData.getAttr(DIR));
	args.setAttr(_taskData.getAttr(ISM));
	args.setAttr(_taskData.getAttr(BUILD_STYLE));
	if (_taskData.getBoolean(CREATE_ROOT)) {
	    String root = _taskData.getString(ROOT);
	    if (root.length() > 0) {
		args.setString(ROOT, root);
	    }
	    String troot = _taskData.getString(TROOT);
	    if (troot.length() > 0) {
		args.setString(TROOT, troot);
	    }
	}

	_privProc = _taskContext.getHostContext().getPrivBroker().
	    runPriv("mkrhinoism", args);
	_watcher = new ProcessWatcher(_privProc);
	_privListener = new PrivListener();
	_watcher.addProcessListener(_privListener);
	_watcher.startWatching();
	try {
	    _privProc.getOutputStream().close();
	} catch (IOException ex) {
	    Log.debug(_class, ex.getMessage());
	    Log.debug(_class, SysUtil.stackTraceToString(ex));
	}
    }

    protected void taskSucceeded(ResultEvent event) {
	super.taskSucceeded(event);
    }

    protected void taskFailed(ResultEvent event) {
	super.taskFailed(event);
    }

    public ResultViewPanel createResultViewPanel() {
	return new ResultViewPanel(
	    _taskContext,
	    _rs,
	    (TaskLoader[])null,
	    MessageFormat.format(_rs.getString("taskSucceeded"),
				 new Object[] {_taskData.getString(DIR)} ));
    }
}
